import math
#from fuzzywuzzy import fuzz
#from fuzzywuzzy import process


# settings

alfabet = [['q','Q'],['w','W'],['e','E'],['r','R'],
['t','T'],['y','Y'],['u','U'],['i','I'],['o','O'],
['p','P'],['a','A'],['s','S'],['d','D'],['f','F'],
['g','G'],['h','H'],['j','J'],['k','K'],['l','L'],
['z','Z'],['x','X'],['c','C'],['v','V'],['b','B'],
['n','N'],['m','M']]


def num_match_max(num1, num2):
	if num1 > num2:
		return num1
	else:
		return num2

def num_match_min(num1, num2):
	if num1 > num2:
		return num2
	else:
		return num1

def one_register(str1):
	i=0
	while i<len(str1):
		j=0
		while j<26:
			if str1[i] == alfabet[j][1]:
				str1 = str1.replace(alfabet[j][1], alfabet[j][0])
			j+=1
		i+=1
	return str1


def ungreat_match(str1,str2,mkdefolt=0.7,mismatching_chars=5):
	i=0
	lenth1 = len(str1)
	lenth2 = len(str2)
	mk = 0
	min_num = num_match_min(lenth1, lenth2)
	str1 = one_register(str1)
	str2 = one_register(str2)
	if str1 == str2:
		keys = [str1, 'True']
		return keys
	elif math.fabs(lenth1 - lenth2) > mismatching_chars:
		test = 1
		keys = ['mismatching skills', 'False', test]
		return keys
	else:
		for char in str1:
			if i < min_num:
				if char == str2[i]:
					mk+=1
			i+=1
		if (mk >=  (min_num*mkdefolt)):
			if min_num == lenth1:
				keys = [str1, 'True']
			elif min_num == lenth2:
				keys = [str2, 'True']
			return keys
		else:
			test = 2
			keys = ['mismatching skills', 'False',test]
			return keys



from ungreat_matching import ungreat_match, num_match_max, num_match_min


test_data = [['python','Python'],
['python','python3.7'],
['PYTHON','python3.7'],
['PYTHON','python3.7.3']]
wrong_test_data = [['Css','Python'],['html','test'],['mess','test'],['have done','succesfully']]
for data in test_data:
    print(ungreat_match(data[0],data[1], mismatching_chars=5, mkdefolt=0.7))
for data in wrong_test_data:
    print(ungreat_match(data[0],data[1], mismatching_chars=5, mkdefolt=0.7))



# from setuptools import setup
#
# setup(name='unmatch',
#       version='1.0.0',
#       description='ungreat matching of strings module',
#       packages=['unmatch'],
#       author_email='ldr200@mail.ru',
#       zip_safe=False)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="unmatch", # Replace with your own username
    version="1.0.4",
    author="Fallen Nephalem",
    author_email="ldr200@mail.ru",
    description="ungreat matching of strings module",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/FallenNephalem/ungreat_matching",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    license='MIT',
    include_package_data=True,
    zip_safe=False
)
